SpyBOAT Output Report

# SpyBOAT Results Report

# Spatial Summary Statistics

Median and quartiles of the estimated periods for each frame

Median and quartiles of the ridge wavelet power for each frame

Kuramoto order parameter for the phases estimated for each frame

# Output Movie Snapshots

### Frame Nr. 20

### Frame Nr. 27

### Frame Nr. 34

### Frame Nr. 41

### Frame Nr. 48

### Frame Nr. 55

### Frame Nr. 62

### Frame Nr. 69

# Parameters

Name | Value
--- | ---
ncpu | 6
rescale_factor | None
gauss_sigma | None
dt | 1.0
Tmin | 20.0
Tmax | 30.0
nT | 150
Tcutoff | 40.0
win_size | None
masking | None
mask_frame | None
mask_thresh | 0